---
icon: lucide/file-video-camera
---

# File Workspace

The **File Workspace** is designed for direct media previewing. Most of the functionality is identical to the general workspace model described in the [Workspaces Overview](index.md).

However, unlike script-based workspaces, an indexed file supports only a single output.
